==> haskell-src-meta-0.7.0.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.7.0.1
id: haskell-src-meta-0.7.0.1-7WsABa0GVm9ZVPlVApUIR
key: haskell-src-meta-0.7.0.1-7WsABa0GVm9ZVPlVApUIR
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Parse.Careful
    Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.TH.Instances.Lift Language.Haskell.Meta.Utils
abi: 788dfd6b7ca00e67e818c1e575e32ff6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/haskell-src-meta-0.7.0.1
hs-libraries: HShaskell-src-meta-0.7.0.1-7WsABa0GVm9ZVPlVApUIR
depends:
    base-4.9.0.0 haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
    pretty-1.1.3.3 syb-0.6-C65vWCsht6A8uLstpQIXyj
    template-haskell-2.11.0.0 th-orphans-0.13.3-cs9TXYbtCJFIfdSAphexL
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.7.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.7.0.1
id: haskell-src-meta-0.7.0.1-4VzeIQwlsxMHoCB12KSrJd
key: haskell-src-meta-0.7.0.1-4VzeIQwlsxMHoCB12KSrJd
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Parse.Careful
    Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.TH.Instances.Lift Language.Haskell.Meta.Utils
abi: 5847f9ec16cf093d7ae08b554223db53
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/haskell-src-meta-0.7.0.1
hs-libraries: HShaskell-src-meta-0.7.0.1-4VzeIQwlsxMHoCB12KSrJd
depends:
    base-4.9.0.0 haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
    pretty-1.1.3.3 syb-0.6-C65vWCsht6A8uLstpQIXyj
    template-haskell-2.11.0.0 th-orphans-0.13.3-JH0tGvKyTLXGgL9CeBHhV2
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
